@@ -2,9 +2,6 @@
 from __future__ import absolute_import, print_function
 
 from suanpan import path
-from suanpan.lazy_import import lazy_import
-
-pd = lazy_import('pandas')
 
 try:
     from io import StringIO
@@ -13,11 +10,13 @@ except ImportError:
 
 
 def load(file, *args, **kwargs):
+    import pandas as pd
     kwargs.setdefault("index_col", 0)
     return pd.read_csv(file, *args, **kwargs)
 
 
 def loads(string, *args, **kwargs):
+    import pandas as pd
     return pd.read_csv(StringIO(string), *args, **kwargs)
 
 
